from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.UI.Input.XboxController
XINPUT_DLL_A: String = 'xinput1_4.dll'
XINPUT_DLL_W: String = 'xinput1_4.dll'
XINPUT_DLL: String = 'xinput1_4.dll'
XUSER_MAX_COUNT: UInt32 = 4
XUSER_INDEX_ANY: UInt32 = 255
@winfunctype('xinput1_4.dll')
def XInputGetState(dwUserIndex: UInt32, pState: POINTER(win32more.Windows.Win32.UI.Input.XboxController.XINPUT_STATE)) -> UInt32: ...
@winfunctype('xinput1_4.dll')
def XInputSetState(dwUserIndex: UInt32, pVibration: POINTER(win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIBRATION)) -> UInt32: ...
@winfunctype('xinput1_4.dll')
def XInputGetCapabilities(dwUserIndex: UInt32, dwFlags: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_FLAG, pCapabilities: POINTER(win32more.Windows.Win32.UI.Input.XboxController.XINPUT_CAPABILITIES)) -> UInt32: ...
@winfunctype('xinput1_4.dll')
def XInputEnable(enable: win32more.Windows.Win32.Foundation.BOOL) -> Void: ...
@winfunctype('xinput1_4.dll')
def XInputGetAudioDeviceIds(dwUserIndex: UInt32, pRenderDeviceId: win32more.Windows.Win32.Foundation.PWSTR, pRenderCount: POINTER(UInt32), pCaptureDeviceId: win32more.Windows.Win32.Foundation.PWSTR, pCaptureCount: POINTER(UInt32)) -> UInt32: ...
@winfunctype('xinput1_4.dll')
def XInputGetBatteryInformation(dwUserIndex: UInt32, devType: win32more.Windows.Win32.UI.Input.XboxController.BATTERY_DEVTYPE, pBatteryInformation: POINTER(win32more.Windows.Win32.UI.Input.XboxController.XINPUT_BATTERY_INFORMATION)) -> UInt32: ...
@winfunctype('xinput1_4.dll')
def XInputGetKeystroke(dwUserIndex: UInt32, dwReserved: UInt32, pKeystroke: POINTER(win32more.Windows.Win32.UI.Input.XboxController.XINPUT_KEYSTROKE)) -> UInt32: ...
BATTERY_DEVTYPE = Byte
BATTERY_DEVTYPE_GAMEPAD: win32more.Windows.Win32.UI.Input.XboxController.BATTERY_DEVTYPE = 0
BATTERY_DEVTYPE_HEADSET: win32more.Windows.Win32.UI.Input.XboxController.BATTERY_DEVTYPE = 1
BATTERY_LEVEL = Byte
BATTERY_LEVEL_EMPTY: win32more.Windows.Win32.UI.Input.XboxController.BATTERY_LEVEL = 0
BATTERY_LEVEL_LOW: win32more.Windows.Win32.UI.Input.XboxController.BATTERY_LEVEL = 1
BATTERY_LEVEL_MEDIUM: win32more.Windows.Win32.UI.Input.XboxController.BATTERY_LEVEL = 2
BATTERY_LEVEL_FULL: win32more.Windows.Win32.UI.Input.XboxController.BATTERY_LEVEL = 3
BATTERY_TYPE = Byte
BATTERY_TYPE_DISCONNECTED: win32more.Windows.Win32.UI.Input.XboxController.BATTERY_TYPE = 0
BATTERY_TYPE_WIRED: win32more.Windows.Win32.UI.Input.XboxController.BATTERY_TYPE = 1
BATTERY_TYPE_ALKALINE: win32more.Windows.Win32.UI.Input.XboxController.BATTERY_TYPE = 2
BATTERY_TYPE_NIMH: win32more.Windows.Win32.UI.Input.XboxController.BATTERY_TYPE = 3
BATTERY_TYPE_UNKNOWN: win32more.Windows.Win32.UI.Input.XboxController.BATTERY_TYPE = 255
class XINPUT_BATTERY_INFORMATION(Structure):
    BatteryType: win32more.Windows.Win32.UI.Input.XboxController.BATTERY_TYPE
    BatteryLevel: win32more.Windows.Win32.UI.Input.XboxController.BATTERY_LEVEL
class XINPUT_CAPABILITIES(Structure):
    Type: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_DEVTYPE
    SubType: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_DEVSUBTYPE
    Flags: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_CAPABILITIES_FLAGS
    Gamepad: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD
    Vibration: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIBRATION
XINPUT_CAPABILITIES_FLAGS = UInt16
XINPUT_CAPS_VOICE_SUPPORTED: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_CAPABILITIES_FLAGS = 4
XINPUT_CAPS_FFB_SUPPORTED: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_CAPABILITIES_FLAGS = 1
XINPUT_CAPS_WIRELESS: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_CAPABILITIES_FLAGS = 2
XINPUT_CAPS_PMD_SUPPORTED: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_CAPABILITIES_FLAGS = 8
XINPUT_CAPS_NO_NAVIGATION: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_CAPABILITIES_FLAGS = 16
XINPUT_DEVSUBTYPE = Byte
XINPUT_DEVSUBTYPE_GAMEPAD: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_DEVSUBTYPE = 1
XINPUT_DEVSUBTYPE_UNKNOWN: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_DEVSUBTYPE = 0
XINPUT_DEVSUBTYPE_WHEEL: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_DEVSUBTYPE = 2
XINPUT_DEVSUBTYPE_ARCADE_STICK: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_DEVSUBTYPE = 3
XINPUT_DEVSUBTYPE_FLIGHT_STICK: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_DEVSUBTYPE = 4
XINPUT_DEVSUBTYPE_DANCE_PAD: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_DEVSUBTYPE = 5
XINPUT_DEVSUBTYPE_GUITAR: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_DEVSUBTYPE = 6
XINPUT_DEVSUBTYPE_GUITAR_ALTERNATE: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_DEVSUBTYPE = 7
XINPUT_DEVSUBTYPE_DRUM_KIT: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_DEVSUBTYPE = 8
XINPUT_DEVSUBTYPE_GUITAR_BASS: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_DEVSUBTYPE = 11
XINPUT_DEVSUBTYPE_ARCADE_PAD: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_DEVSUBTYPE = 19
XINPUT_DEVTYPE = Byte
XINPUT_DEVTYPE_GAMEPAD: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_DEVTYPE = 1
XINPUT_FLAG = UInt32
XINPUT_FLAG_ALL: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_FLAG = 0
XINPUT_FLAG_GAMEPAD: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_FLAG = 1
class XINPUT_GAMEPAD(Structure):
    wButtons: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD_BUTTON_FLAGS
    bLeftTrigger: Byte
    bRightTrigger: Byte
    sThumbLX: Int16
    sThumbLY: Int16
    sThumbRX: Int16
    sThumbRY: Int16
XINPUT_GAMEPAD_BUTTON_FLAGS = UInt16
XINPUT_GAMEPAD_DPAD_UP: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD_BUTTON_FLAGS = 1
XINPUT_GAMEPAD_DPAD_DOWN: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD_BUTTON_FLAGS = 2
XINPUT_GAMEPAD_DPAD_LEFT: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD_BUTTON_FLAGS = 4
XINPUT_GAMEPAD_DPAD_RIGHT: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD_BUTTON_FLAGS = 8
XINPUT_GAMEPAD_START: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD_BUTTON_FLAGS = 16
XINPUT_GAMEPAD_BACK: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD_BUTTON_FLAGS = 32
XINPUT_GAMEPAD_LEFT_THUMB: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD_BUTTON_FLAGS = 64
XINPUT_GAMEPAD_RIGHT_THUMB: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD_BUTTON_FLAGS = 128
XINPUT_GAMEPAD_LEFT_SHOULDER: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD_BUTTON_FLAGS = 256
XINPUT_GAMEPAD_RIGHT_SHOULDER: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD_BUTTON_FLAGS = 512
XINPUT_GAMEPAD_A: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD_BUTTON_FLAGS = 4096
XINPUT_GAMEPAD_B: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD_BUTTON_FLAGS = 8192
XINPUT_GAMEPAD_X: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD_BUTTON_FLAGS = 16384
XINPUT_GAMEPAD_Y: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD_BUTTON_FLAGS = 32768
XINPUT_GAMEPAD_LEFT_THUMB_DEADZONE: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD_BUTTON_FLAGS = 7849
XINPUT_GAMEPAD_RIGHT_THUMB_DEADZONE: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD_BUTTON_FLAGS = 8689
XINPUT_GAMEPAD_TRIGGER_THRESHOLD: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD_BUTTON_FLAGS = 30
class XINPUT_KEYSTROKE(Structure):
    VirtualKey: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY
    Unicode: Char
    Flags: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_KEYSTROKE_FLAGS
    UserIndex: Byte
    HidCode: Byte
XINPUT_KEYSTROKE_FLAGS = UInt16
XINPUT_KEYSTROKE_KEYDOWN: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_KEYSTROKE_FLAGS = 1
XINPUT_KEYSTROKE_KEYUP: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_KEYSTROKE_FLAGS = 2
XINPUT_KEYSTROKE_REPEAT: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_KEYSTROKE_FLAGS = 4
class XINPUT_STATE(Structure):
    dwPacketNumber: UInt32
    Gamepad: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_GAMEPAD
class XINPUT_VIBRATION(Structure):
    wLeftMotorSpeed: UInt16
    wRightMotorSpeed: UInt16
XINPUT_VIRTUAL_KEY = UInt16
VK_PAD_A: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22528
VK_PAD_B: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22529
VK_PAD_X: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22530
VK_PAD_Y: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22531
VK_PAD_RSHOULDER: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22532
VK_PAD_LSHOULDER: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22533
VK_PAD_LTRIGGER: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22534
VK_PAD_RTRIGGER: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22535
VK_PAD_DPAD_UP: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22544
VK_PAD_DPAD_DOWN: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22545
VK_PAD_DPAD_LEFT: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22546
VK_PAD_DPAD_RIGHT: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22547
VK_PAD_START: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22548
VK_PAD_BACK: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22549
VK_PAD_LTHUMB_PRESS: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22550
VK_PAD_RTHUMB_PRESS: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22551
VK_PAD_LTHUMB_UP: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22560
VK_PAD_LTHUMB_DOWN: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22561
VK_PAD_LTHUMB_RIGHT: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22562
VK_PAD_LTHUMB_LEFT: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22563
VK_PAD_LTHUMB_UPLEFT: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22564
VK_PAD_LTHUMB_UPRIGHT: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22565
VK_PAD_LTHUMB_DOWNRIGHT: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22566
VK_PAD_LTHUMB_DOWNLEFT: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22567
VK_PAD_RTHUMB_UP: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22576
VK_PAD_RTHUMB_DOWN: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22577
VK_PAD_RTHUMB_RIGHT: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22578
VK_PAD_RTHUMB_LEFT: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22579
VK_PAD_RTHUMB_UPLEFT: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22580
VK_PAD_RTHUMB_UPRIGHT: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22581
VK_PAD_RTHUMB_DOWNRIGHT: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22582
VK_PAD_RTHUMB_DOWNLEFT: win32more.Windows.Win32.UI.Input.XboxController.XINPUT_VIRTUAL_KEY = 22583


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Globalization
import win32more.Windows.Media.SpeechRecognition
import win32more.Windows.Storage
import win32more.Windows.Win32.System.WinRT
class ISpeechContinuousRecognitionCompletedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionCompletedEventArgs'
    _iid_ = Guid('{e3d069bb-e30c-5e18-424b-7fbe81f8fbd0}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionResultStatus: ...
    Status = property(get_Status, None)
class ISpeechContinuousRecognitionResultGeneratedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionResultGeneratedEventArgs'
    _iid_ = Guid('{19091e1e-6e7e-5a46-40fb-76594f786504}')
    @winrt_commethod(6)
    def get_Result(self) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionResult: ...
    Result = property(get_Result, None)
class ISpeechContinuousRecognitionSession(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionSession'
    _iid_ = Guid('{6a213c04-6614-49f8-99a2-b5e9b3a085c8}')
    @winrt_commethod(6)
    def get_AutoStopSilenceTimeout(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(7)
    def put_AutoStopSilenceTimeout(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(8)
    def StartAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(9)
    def StartWithModeAsync(self, mode: win32more.Windows.Media.SpeechRecognition.SpeechContinuousRecognitionMode) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(10)
    def StopAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(11)
    def CancelAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(12)
    def PauseAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(13)
    def Resume(self) -> Void: ...
    @winrt_commethod(14)
    def add_Completed(self, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.SpeechRecognition.SpeechContinuousRecognitionSession, win32more.Windows.Media.SpeechRecognition.SpeechContinuousRecognitionCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_Completed(self, value: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def add_ResultGenerated(self, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.SpeechRecognition.SpeechContinuousRecognitionSession, win32more.Windows.Media.SpeechRecognition.SpeechContinuousRecognitionResultGeneratedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_ResultGenerated(self, value: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AutoStopSilenceTimeout = property(get_AutoStopSilenceTimeout, put_AutoStopSilenceTimeout)
    Completed = event()
    ResultGenerated = event()
class ISpeechRecognitionCompilationResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognitionCompilationResult'
    _iid_ = Guid('{407e6c5d-6ac7-4da4-9cc1-2fce32cf7489}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionResultStatus: ...
    Status = property(get_Status, None)
class ISpeechRecognitionConstraint(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint'
    _iid_ = Guid('{79ac1628-4d68-43c4-8911-40dc4101b55b}')
    @winrt_commethod(6)
    def get_IsEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Tag(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_Tag(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_Type(self) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionConstraintType: ...
    @winrt_commethod(11)
    def get_Probability(self) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionConstraintProbability: ...
    @winrt_commethod(12)
    def put_Probability(self, value: win32more.Windows.Media.SpeechRecognition.SpeechRecognitionConstraintProbability) -> Void: ...
    IsEnabled = property(get_IsEnabled, put_IsEnabled)
    Probability = property(get_Probability, put_Probability)
    Tag = property(get_Tag, put_Tag)
    Type = property(get_Type, None)
class ISpeechRecognitionGrammarFileConstraint(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognitionGrammarFileConstraint'
    _iid_ = Guid('{b5031a8f-85ca-4fa4-b11a-474fc41b3835}')
    @winrt_commethod(6)
    def get_GrammarFile(self) -> win32more.Windows.Storage.StorageFile: ...
    GrammarFile = property(get_GrammarFile, None)
class ISpeechRecognitionGrammarFileConstraintFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognitionGrammarFileConstraintFactory'
    _iid_ = Guid('{3da770eb-c479-4c27-9f19-89974ef392d1}')
    @winrt_commethod(6)
    def Create(self, file: win32more.Windows.Storage.StorageFile) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionGrammarFileConstraint: ...
    @winrt_commethod(7)
    def CreateWithTag(self, file: win32more.Windows.Storage.StorageFile, tag: WinRT_String) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionGrammarFileConstraint: ...
class ISpeechRecognitionHypothesis(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognitionHypothesis'
    _iid_ = Guid('{7a7b25b0-99c5-4f7d-bf84-10aa1302b634}')
    @winrt_commethod(6)
    def get_Text(self) -> WinRT_String: ...
    Text = property(get_Text, None)
class ISpeechRecognitionHypothesisGeneratedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognitionHypothesisGeneratedEventArgs'
    _iid_ = Guid('{55161a7a-8023-5866-411d-1213bb271476}')
    @winrt_commethod(6)
    def get_Hypothesis(self) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionHypothesis: ...
    Hypothesis = property(get_Hypothesis, None)
class ISpeechRecognitionListConstraint(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognitionListConstraint'
    _iid_ = Guid('{09c487e9-e4ad-4526-81f2-4946fb481d98}')
    @winrt_commethod(6)
    def get_Commands(self) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    Commands = property(get_Commands, None)
class ISpeechRecognitionListConstraintFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognitionListConstraintFactory'
    _iid_ = Guid('{40f3cdc7-562a-426a-9f3b-3b4e282be1d5}')
    @winrt_commethod(6)
    def Create(self, commands: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionListConstraint: ...
    @winrt_commethod(7)
    def CreateWithTag(self, commands: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], tag: WinRT_String) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionListConstraint: ...
class ISpeechRecognitionQualityDegradingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognitionQualityDegradingEventArgs'
    _iid_ = Guid('{4fe24105-8c3a-4c7e-8d0a-5bd4f5b14ad8}')
    @winrt_commethod(6)
    def get_Problem(self) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionAudioProblem: ...
    Problem = property(get_Problem, None)
class ISpeechRecognitionResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognitionResult'
    _iid_ = Guid('{4e303157-034e-4652-857e-d0454cc4beec}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionResultStatus: ...
    @winrt_commethod(7)
    def get_Text(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_Confidence(self) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionConfidence: ...
    @winrt_commethod(9)
    def get_SemanticInterpretation(self) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionSemanticInterpretation: ...
    @winrt_commethod(10)
    def GetAlternates(self, maxAlternates: UInt32) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Media.SpeechRecognition.SpeechRecognitionResult]: ...
    @winrt_commethod(11)
    def get_Constraint(self) -> win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint: ...
    @winrt_commethod(12)
    def get_RulePath(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_commethod(13)
    def get_RawConfidence(self) -> Double: ...
    Confidence = property(get_Confidence, None)
    Constraint = property(get_Constraint, None)
    RawConfidence = property(get_RawConfidence, None)
    RulePath = property(get_RulePath, None)
    SemanticInterpretation = property(get_SemanticInterpretation, None)
    Status = property(get_Status, None)
    Text = property(get_Text, None)
class ISpeechRecognitionResult2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognitionResult2'
    _iid_ = Guid('{af7ed1ba-451b-4166-a0c1-1ffe84032d03}')
    @winrt_commethod(6)
    def get_PhraseStartTime(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(7)
    def get_PhraseDuration(self) -> win32more.Windows.Foundation.TimeSpan: ...
    PhraseDuration = property(get_PhraseDuration, None)
    PhraseStartTime = property(get_PhraseStartTime, None)
class ISpeechRecognitionSemanticInterpretation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognitionSemanticInterpretation'
    _iid_ = Guid('{aae1da9b-7e32-4c1f-89fe-0c65f486f52e}')
    @winrt_commethod(6)
    def get_Properties(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
    Properties = property(get_Properties, None)
class ISpeechRecognitionTopicConstraint(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognitionTopicConstraint'
    _iid_ = Guid('{bf6fdf19-825d-4e69-a681-36e48cf1c93e}')
    @winrt_commethod(6)
    def get_Scenario(self) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionScenario: ...
    @winrt_commethod(7)
    def get_TopicHint(self) -> WinRT_String: ...
    Scenario = property(get_Scenario, None)
    TopicHint = property(get_TopicHint, None)
class ISpeechRecognitionTopicConstraintFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognitionTopicConstraintFactory'
    _iid_ = Guid('{6e6863df-ec05-47d7-a5df-56a3431e58d2}')
    @winrt_commethod(6)
    def Create(self, scenario: win32more.Windows.Media.SpeechRecognition.SpeechRecognitionScenario, topicHint: WinRT_String) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionTopicConstraint: ...
    @winrt_commethod(7)
    def CreateWithTag(self, scenario: win32more.Windows.Media.SpeechRecognition.SpeechRecognitionScenario, topicHint: WinRT_String, tag: WinRT_String) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionTopicConstraint: ...
class ISpeechRecognitionVoiceCommandDefinitionConstraint(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognitionVoiceCommandDefinitionConstraint'
    _iid_ = Guid('{f2791c2b-1ef4-4ae7-9d77-b6ff10b8a3c2}')
class ISpeechRecognizer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognizer'
    _iid_ = Guid('{0bc3c9cb-c26a-40f2-aeb5-8096b2e48073}')
    @winrt_commethod(6)
    def get_CurrentLanguage(self) -> win32more.Windows.Globalization.Language: ...
    @winrt_commethod(7)
    def get_Constraints(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint]: ...
    @winrt_commethod(8)
    def get_Timeouts(self) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognizerTimeouts: ...
    @winrt_commethod(9)
    def get_UIOptions(self) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognizerUIOptions: ...
    @winrt_commethod(10)
    def CompileConstraintsAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.SpeechRecognition.SpeechRecognitionCompilationResult]: ...
    @winrt_commethod(11)
    def RecognizeAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.SpeechRecognition.SpeechRecognitionResult]: ...
    @winrt_commethod(12)
    def RecognizeWithUIAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.SpeechRecognition.SpeechRecognitionResult]: ...
    @winrt_commethod(13)
    def add_RecognitionQualityDegrading(self, speechRecognitionQualityDegradingHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.SpeechRecognition.SpeechRecognizer, win32more.Windows.Media.SpeechRecognition.SpeechRecognitionQualityDegradingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(14)
    def remove_RecognitionQualityDegrading(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(15)
    def add_StateChanged(self, stateChangedHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.SpeechRecognition.SpeechRecognizer, win32more.Windows.Media.SpeechRecognition.SpeechRecognizerStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(16)
    def remove_StateChanged(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Constraints = property(get_Constraints, None)
    CurrentLanguage = property(get_CurrentLanguage, None)
    Timeouts = property(get_Timeouts, None)
    UIOptions = property(get_UIOptions, None)
    RecognitionQualityDegrading = event()
    StateChanged = event()
class ISpeechRecognizer2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognizer2'
    _iid_ = Guid('{63c9baf1-91e3-4ea4-86a1-7c3867d084a6}')
    @winrt_commethod(6)
    def get_ContinuousRecognitionSession(self) -> win32more.Windows.Media.SpeechRecognition.SpeechContinuousRecognitionSession: ...
    @winrt_commethod(7)
    def get_State(self) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognizerState: ...
    @winrt_commethod(8)
    def StopRecognitionAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(9)
    def add_HypothesisGenerated(self, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.SpeechRecognition.SpeechRecognizer, win32more.Windows.Media.SpeechRecognition.SpeechRecognitionHypothesisGeneratedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_HypothesisGenerated(self, value: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ContinuousRecognitionSession = property(get_ContinuousRecognitionSession, None)
    State = property(get_State, None)
    HypothesisGenerated = event()
class ISpeechRecognizerFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognizerFactory'
    _iid_ = Guid('{60c488dd-7fb8-4033-ac70-d046f64818e1}')
    @winrt_commethod(6)
    def Create(self, language: win32more.Windows.Globalization.Language) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognizer: ...
class ISpeechRecognizerStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognizerStateChangedEventArgs'
    _iid_ = Guid('{563d4f09-ba03-4bad-ad81-ddc6c4dab0c3}')
    @winrt_commethod(6)
    def get_State(self) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognizerState: ...
    State = property(get_State, None)
class ISpeechRecognizerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognizerStatics'
    _iid_ = Guid('{87a35eac-a7dc-4b0b-bcc9-24f47c0b7ebf}')
    @winrt_commethod(6)
    def get_SystemSpeechLanguage(self) -> win32more.Windows.Globalization.Language: ...
    @winrt_commethod(7)
    def get_SupportedTopicLanguages(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Globalization.Language]: ...
    @winrt_commethod(8)
    def get_SupportedGrammarLanguages(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Globalization.Language]: ...
    SupportedGrammarLanguages = property(get_SupportedGrammarLanguages, None)
    SupportedTopicLanguages = property(get_SupportedTopicLanguages, None)
    SystemSpeechLanguage = property(get_SystemSpeechLanguage, None)
class ISpeechRecognizerStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognizerStatics2'
    _iid_ = Guid('{1d1b0d95-7565-4ef9-a2f3-ba15162a96cf}')
    @winrt_commethod(6)
    def TrySetSystemSpeechLanguageAsync(self, speechLanguage: win32more.Windows.Globalization.Language) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
class ISpeechRecognizerTimeouts(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognizerTimeouts'
    _iid_ = Guid('{2ef76fca-6a3c-4dca-a153-df1bc88a79af}')
    @winrt_commethod(6)
    def get_InitialSilenceTimeout(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(7)
    def put_InitialSilenceTimeout(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(8)
    def get_EndSilenceTimeout(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(9)
    def put_EndSilenceTimeout(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(10)
    def get_BabbleTimeout(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(11)
    def put_BabbleTimeout(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    BabbleTimeout = property(get_BabbleTimeout, put_BabbleTimeout)
    EndSilenceTimeout = property(get_EndSilenceTimeout, put_EndSilenceTimeout)
    InitialSilenceTimeout = property(get_InitialSilenceTimeout, put_InitialSilenceTimeout)
class ISpeechRecognizerUIOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.ISpeechRecognizerUIOptions'
    _iid_ = Guid('{7888d641-b92b-44ba-a25f-d1864630641f}')
    @winrt_commethod(6)
    def get_ExampleText(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_ExampleText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_AudiblePrompt(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_AudiblePrompt(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_IsReadBackEnabled(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsReadBackEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_ShowConfirmation(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_ShowConfirmation(self, value: Boolean) -> Void: ...
    AudiblePrompt = property(get_AudiblePrompt, put_AudiblePrompt)
    ExampleText = property(get_ExampleText, put_ExampleText)
    IsReadBackEnabled = property(get_IsReadBackEnabled, put_IsReadBackEnabled)
    ShowConfirmation = property(get_ShowConfirmation, put_ShowConfirmation)
class IVoiceCommandManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.IVoiceCommandManager'
    _iid_ = Guid('{aa3a8dd5-b6e7-4ee2-baa9-dd6baced0a2b}')
    @winrt_commethod(6)
    def InstallCommandSetsFromStorageFileAsync(self, file: win32more.Windows.Storage.StorageFile) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def get_InstalledCommandSets(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Media.SpeechRecognition.VoiceCommandSet]: ...
    InstalledCommandSets = property(get_InstalledCommandSets, None)
class IVoiceCommandSet(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.IVoiceCommandSet'
    _iid_ = Guid('{0bedda75-46e6-4b11-a088-5c68632899b5}')
    @winrt_commethod(6)
    def get_Language(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def SetPhraseListAsync(self, phraseListName: WinRT_String, phraseList: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncAction: ...
    Language = property(get_Language, None)
    Name = property(get_Name, None)
class SpeechContinuousRecognitionCompletedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionCompletedEventArgs
    _classid_ = 'Windows.Media.SpeechRecognition.SpeechContinuousRecognitionCompletedEventArgs'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionCompletedEventArgs) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionResultStatus: ...
    Status = property(get_Status, None)
class SpeechContinuousRecognitionMode(Enum, Int32):
    Default = 0
    PauseOnRecognition = 1
class SpeechContinuousRecognitionResultGeneratedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionResultGeneratedEventArgs
    _classid_ = 'Windows.Media.SpeechRecognition.SpeechContinuousRecognitionResultGeneratedEventArgs'
    @winrt_mixinmethod
    def get_Result(self: win32more.Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionResultGeneratedEventArgs) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionResult: ...
    Result = property(get_Result, None)
class SpeechContinuousRecognitionSession(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionSession
    _classid_ = 'Windows.Media.SpeechRecognition.SpeechContinuousRecognitionSession'
    @winrt_mixinmethod
    def get_AutoStopSilenceTimeout(self: win32more.Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionSession) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_AutoStopSilenceTimeout(self: win32more.Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionSession, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def StartAsync(self: win32more.Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionSession) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def StartWithModeAsync(self: win32more.Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionSession, mode: win32more.Windows.Media.SpeechRecognition.SpeechContinuousRecognitionMode) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def StopAsync(self: win32more.Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionSession) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def CancelAsync(self: win32more.Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionSession) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def PauseAsync(self: win32more.Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionSession) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def Resume(self: win32more.Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionSession) -> Void: ...
    @winrt_mixinmethod
    def add_Completed(self: win32more.Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionSession, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.SpeechRecognition.SpeechContinuousRecognitionSession, win32more.Windows.Media.SpeechRecognition.SpeechContinuousRecognitionCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Completed(self: win32more.Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionSession, value: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ResultGenerated(self: win32more.Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionSession, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.SpeechRecognition.SpeechContinuousRecognitionSession, win32more.Windows.Media.SpeechRecognition.SpeechContinuousRecognitionResultGeneratedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ResultGenerated(self: win32more.Windows.Media.SpeechRecognition.ISpeechContinuousRecognitionSession, value: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AutoStopSilenceTimeout = property(get_AutoStopSilenceTimeout, put_AutoStopSilenceTimeout)
    Completed = event()
    ResultGenerated = event()
class SpeechRecognitionAudioProblem(Enum, Int32):
    None_ = 0
    TooNoisy = 1
    NoSignal = 2
    TooLoud = 3
    TooQuiet = 4
    TooFast = 5
    TooSlow = 6
class SpeechRecognitionCompilationResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionCompilationResult
    _classid_ = 'Windows.Media.SpeechRecognition.SpeechRecognitionCompilationResult'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionCompilationResult) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionResultStatus: ...
    Status = property(get_Status, None)
class SpeechRecognitionConfidence(Enum, Int32):
    High = 0
    Medium = 1
    Low = 2
    Rejected = 3
class SpeechRecognitionConstraintProbability(Enum, Int32):
    Default = 0
    Min = 1
    Max = 2
class SpeechRecognitionConstraintType(Enum, Int32):
    Topic = 0
    List = 1
    Grammar = 2
    VoiceCommandDefinition = 3
class SpeechRecognitionGrammarFileConstraint(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionGrammarFileConstraint
    _classid_ = 'Windows.Media.SpeechRecognition.SpeechRecognitionGrammarFileConstraint'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Media.SpeechRecognition.SpeechRecognitionGrammarFileConstraint.Create(*args))
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.Media.SpeechRecognition.SpeechRecognitionGrammarFileConstraint.CreateWithTag(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionGrammarFileConstraintFactory, file: win32more.Windows.Storage.StorageFile) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionGrammarFileConstraint: ...
    @winrt_factorymethod
    def CreateWithTag(cls: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionGrammarFileConstraintFactory, file: win32more.Windows.Storage.StorageFile, tag: WinRT_String) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionGrammarFileConstraint: ...
    @winrt_mixinmethod
    def get_GrammarFile(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionGrammarFileConstraint) -> win32more.Windows.Storage.StorageFile: ...
    @winrt_mixinmethod
    def get_IsEnabled(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsEnabled(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Tag(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Tag(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Type(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionConstraintType: ...
    @winrt_mixinmethod
    def get_Probability(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionConstraintProbability: ...
    @winrt_mixinmethod
    def put_Probability(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint, value: win32more.Windows.Media.SpeechRecognition.SpeechRecognitionConstraintProbability) -> Void: ...
    GrammarFile = property(get_GrammarFile, None)
    IsEnabled = property(get_IsEnabled, put_IsEnabled)
    Probability = property(get_Probability, put_Probability)
    Tag = property(get_Tag, put_Tag)
    Type = property(get_Type, None)
class SpeechRecognitionHypothesis(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionHypothesis
    _classid_ = 'Windows.Media.SpeechRecognition.SpeechRecognitionHypothesis'
    @winrt_mixinmethod
    def get_Text(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionHypothesis) -> WinRT_String: ...
    Text = property(get_Text, None)
class SpeechRecognitionHypothesisGeneratedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionHypothesisGeneratedEventArgs
    _classid_ = 'Windows.Media.SpeechRecognition.SpeechRecognitionHypothesisGeneratedEventArgs'
    @winrt_mixinmethod
    def get_Hypothesis(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionHypothesisGeneratedEventArgs) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionHypothesis: ...
    Hypothesis = property(get_Hypothesis, None)
class SpeechRecognitionListConstraint(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionListConstraint
    _classid_ = 'Windows.Media.SpeechRecognition.SpeechRecognitionListConstraint'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Media.SpeechRecognition.SpeechRecognitionListConstraint.Create(*args))
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.Media.SpeechRecognition.SpeechRecognitionListConstraint.CreateWithTag(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionListConstraintFactory, commands: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionListConstraint: ...
    @winrt_factorymethod
    def CreateWithTag(cls: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionListConstraintFactory, commands: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], tag: WinRT_String) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionListConstraint: ...
    @winrt_mixinmethod
    def get_Commands(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionListConstraint) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @winrt_mixinmethod
    def get_IsEnabled(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsEnabled(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Tag(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Tag(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Type(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionConstraintType: ...
    @winrt_mixinmethod
    def get_Probability(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionConstraintProbability: ...
    @winrt_mixinmethod
    def put_Probability(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint, value: win32more.Windows.Media.SpeechRecognition.SpeechRecognitionConstraintProbability) -> Void: ...
    Commands = property(get_Commands, None)
    IsEnabled = property(get_IsEnabled, put_IsEnabled)
    Probability = property(get_Probability, put_Probability)
    Tag = property(get_Tag, put_Tag)
    Type = property(get_Type, None)
class SpeechRecognitionQualityDegradingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionQualityDegradingEventArgs
    _classid_ = 'Windows.Media.SpeechRecognition.SpeechRecognitionQualityDegradingEventArgs'
    @winrt_mixinmethod
    def get_Problem(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionQualityDegradingEventArgs) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionAudioProblem: ...
    Problem = property(get_Problem, None)
class SpeechRecognitionResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionResult
    _classid_ = 'Windows.Media.SpeechRecognition.SpeechRecognitionResult'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionResult) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionResultStatus: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionResult) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Confidence(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionResult) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionConfidence: ...
    @winrt_mixinmethod
    def get_SemanticInterpretation(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionResult) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionSemanticInterpretation: ...
    @winrt_mixinmethod
    def GetAlternates(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionResult, maxAlternates: UInt32) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Media.SpeechRecognition.SpeechRecognitionResult]: ...
    @winrt_mixinmethod
    def get_Constraint(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionResult) -> win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint: ...
    @winrt_mixinmethod
    def get_RulePath(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionResult) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def get_RawConfidence(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionResult) -> Double: ...
    @winrt_mixinmethod
    def get_PhraseStartTime(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionResult2) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def get_PhraseDuration(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionResult2) -> win32more.Windows.Foundation.TimeSpan: ...
    Confidence = property(get_Confidence, None)
    Constraint = property(get_Constraint, None)
    PhraseDuration = property(get_PhraseDuration, None)
    PhraseStartTime = property(get_PhraseStartTime, None)
    RawConfidence = property(get_RawConfidence, None)
    RulePath = property(get_RulePath, None)
    SemanticInterpretation = property(get_SemanticInterpretation, None)
    Status = property(get_Status, None)
    Text = property(get_Text, None)
class SpeechRecognitionResultStatus(Enum, Int32):
    Success = 0
    TopicLanguageNotSupported = 1
    GrammarLanguageMismatch = 2
    GrammarCompilationFailure = 3
    AudioQualityFailure = 4
    UserCanceled = 5
    Unknown = 6
    TimeoutExceeded = 7
    PauseLimitExceeded = 8
    NetworkFailure = 9
    MicrophoneUnavailable = 10
class SpeechRecognitionScenario(Enum, Int32):
    WebSearch = 0
    Dictation = 1
    FormFilling = 2
class SpeechRecognitionSemanticInterpretation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionSemanticInterpretation
    _classid_ = 'Windows.Media.SpeechRecognition.SpeechRecognitionSemanticInterpretation'
    @winrt_mixinmethod
    def get_Properties(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionSemanticInterpretation) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
    Properties = property(get_Properties, None)
class SpeechRecognitionTopicConstraint(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionTopicConstraint
    _classid_ = 'Windows.Media.SpeechRecognition.SpeechRecognitionTopicConstraint'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.Media.SpeechRecognition.SpeechRecognitionTopicConstraint.Create(*args))
        elif len(args) == 3:
            super().__init__(move=win32more.Windows.Media.SpeechRecognition.SpeechRecognitionTopicConstraint.CreateWithTag(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionTopicConstraintFactory, scenario: win32more.Windows.Media.SpeechRecognition.SpeechRecognitionScenario, topicHint: WinRT_String) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionTopicConstraint: ...
    @winrt_factorymethod
    def CreateWithTag(cls: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionTopicConstraintFactory, scenario: win32more.Windows.Media.SpeechRecognition.SpeechRecognitionScenario, topicHint: WinRT_String, tag: WinRT_String) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionTopicConstraint: ...
    @winrt_mixinmethod
    def get_Scenario(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionTopicConstraint) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionScenario: ...
    @winrt_mixinmethod
    def get_TopicHint(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionTopicConstraint) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_IsEnabled(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsEnabled(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Tag(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Tag(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Type(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionConstraintType: ...
    @winrt_mixinmethod
    def get_Probability(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionConstraintProbability: ...
    @winrt_mixinmethod
    def put_Probability(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint, value: win32more.Windows.Media.SpeechRecognition.SpeechRecognitionConstraintProbability) -> Void: ...
    IsEnabled = property(get_IsEnabled, put_IsEnabled)
    Probability = property(get_Probability, put_Probability)
    Scenario = property(get_Scenario, None)
    Tag = property(get_Tag, put_Tag)
    TopicHint = property(get_TopicHint, None)
    Type = property(get_Type, None)
class SpeechRecognitionVoiceCommandDefinitionConstraint(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionVoiceCommandDefinitionConstraint
    _classid_ = 'Windows.Media.SpeechRecognition.SpeechRecognitionVoiceCommandDefinitionConstraint'
    @winrt_mixinmethod
    def get_IsEnabled(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsEnabled(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Tag(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Tag(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Type(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionConstraintType: ...
    @winrt_mixinmethod
    def get_Probability(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognitionConstraintProbability: ...
    @winrt_mixinmethod
    def put_Probability(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint, value: win32more.Windows.Media.SpeechRecognition.SpeechRecognitionConstraintProbability) -> Void: ...
    IsEnabled = property(get_IsEnabled, put_IsEnabled)
    Probability = property(get_Probability, put_Probability)
    Tag = property(get_Tag, put_Tag)
    Type = property(get_Type, None)
class _SpeechRecognizer_Meta_(ComPtr.__class__):
    pass
class SpeechRecognizer(ComPtr, metaclass=_SpeechRecognizer_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizer
    _classid_ = 'Windows.Media.SpeechRecognition.SpeechRecognizer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Media.SpeechRecognition.SpeechRecognizer.CreateInstance(*args))
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Media.SpeechRecognition.SpeechRecognizer.Create(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognizer: ...
    @winrt_factorymethod
    def Create(cls: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerFactory, language: win32more.Windows.Globalization.Language) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognizer: ...
    @winrt_mixinmethod
    def get_CurrentLanguage(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizer) -> win32more.Windows.Globalization.Language: ...
    @winrt_mixinmethod
    def get_Constraints(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizer) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Media.SpeechRecognition.ISpeechRecognitionConstraint]: ...
    @winrt_mixinmethod
    def get_Timeouts(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizer) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognizerTimeouts: ...
    @winrt_mixinmethod
    def get_UIOptions(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizer) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognizerUIOptions: ...
    @winrt_mixinmethod
    def CompileConstraintsAsync(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizer) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.SpeechRecognition.SpeechRecognitionCompilationResult]: ...
    @winrt_mixinmethod
    def RecognizeAsync(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizer) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.SpeechRecognition.SpeechRecognitionResult]: ...
    @winrt_mixinmethod
    def RecognizeWithUIAsync(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizer) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.SpeechRecognition.SpeechRecognitionResult]: ...
    @winrt_mixinmethod
    def add_RecognitionQualityDegrading(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizer, speechRecognitionQualityDegradingHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.SpeechRecognition.SpeechRecognizer, win32more.Windows.Media.SpeechRecognition.SpeechRecognitionQualityDegradingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_RecognitionQualityDegrading(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizer, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_StateChanged(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizer, stateChangedHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.SpeechRecognition.SpeechRecognizer, win32more.Windows.Media.SpeechRecognition.SpeechRecognizerStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_StateChanged(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizer, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_mixinmethod
    def get_ContinuousRecognitionSession(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizer2) -> win32more.Windows.Media.SpeechRecognition.SpeechContinuousRecognitionSession: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizer2) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognizerState: ...
    @winrt_mixinmethod
    def StopRecognitionAsync(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizer2) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def add_HypothesisGenerated(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizer2, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.SpeechRecognition.SpeechRecognizer, win32more.Windows.Media.SpeechRecognition.SpeechRecognitionHypothesisGeneratedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_HypothesisGenerated(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizer2, value: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def TrySetSystemSpeechLanguageAsync(cls: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerStatics2, speechLanguage: win32more.Windows.Globalization.Language) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_classmethod
    def get_SystemSpeechLanguage(cls: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerStatics) -> win32more.Windows.Globalization.Language: ...
    @winrt_classmethod
    def get_SupportedTopicLanguages(cls: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerStatics) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Globalization.Language]: ...
    @winrt_classmethod
    def get_SupportedGrammarLanguages(cls: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerStatics) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Globalization.Language]: ...
    Constraints = property(get_Constraints, None)
    ContinuousRecognitionSession = property(get_ContinuousRecognitionSession, None)
    CurrentLanguage = property(get_CurrentLanguage, None)
    State = property(get_State, None)
    Timeouts = property(get_Timeouts, None)
    UIOptions = property(get_UIOptions, None)
    _SpeechRecognizer_Meta_.SupportedGrammarLanguages = property(get_SupportedGrammarLanguages, None)
    _SpeechRecognizer_Meta_.SupportedTopicLanguages = property(get_SupportedTopicLanguages, None)
    _SpeechRecognizer_Meta_.SystemSpeechLanguage = property(get_SystemSpeechLanguage, None)
    RecognitionQualityDegrading = event()
    StateChanged = event()
    HypothesisGenerated = event()
class SpeechRecognizerState(Enum, Int32):
    Idle = 0
    Capturing = 1
    Processing = 2
    SoundStarted = 3
    SoundEnded = 4
    SpeechDetected = 5
    Paused = 6
class SpeechRecognizerStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerStateChangedEventArgs
    _classid_ = 'Windows.Media.SpeechRecognition.SpeechRecognizerStateChangedEventArgs'
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerStateChangedEventArgs) -> win32more.Windows.Media.SpeechRecognition.SpeechRecognizerState: ...
    State = property(get_State, None)
class SpeechRecognizerTimeouts(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerTimeouts
    _classid_ = 'Windows.Media.SpeechRecognition.SpeechRecognizerTimeouts'
    @winrt_mixinmethod
    def get_InitialSilenceTimeout(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerTimeouts) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_InitialSilenceTimeout(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerTimeouts, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_EndSilenceTimeout(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerTimeouts) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_EndSilenceTimeout(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerTimeouts, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_BabbleTimeout(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerTimeouts) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_BabbleTimeout(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerTimeouts, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    BabbleTimeout = property(get_BabbleTimeout, put_BabbleTimeout)
    EndSilenceTimeout = property(get_EndSilenceTimeout, put_EndSilenceTimeout)
    InitialSilenceTimeout = property(get_InitialSilenceTimeout, put_InitialSilenceTimeout)
class SpeechRecognizerUIOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerUIOptions
    _classid_ = 'Windows.Media.SpeechRecognition.SpeechRecognizerUIOptions'
    @winrt_mixinmethod
    def get_ExampleText(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerUIOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_ExampleText(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerUIOptions, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_AudiblePrompt(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerUIOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_AudiblePrompt(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerUIOptions, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_IsReadBackEnabled(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerUIOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsReadBackEnabled(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerUIOptions, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ShowConfirmation(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerUIOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShowConfirmation(self: win32more.Windows.Media.SpeechRecognition.ISpeechRecognizerUIOptions, value: Boolean) -> Void: ...
    AudiblePrompt = property(get_AudiblePrompt, put_AudiblePrompt)
    ExampleText = property(get_ExampleText, put_ExampleText)
    IsReadBackEnabled = property(get_IsReadBackEnabled, put_IsReadBackEnabled)
    ShowConfirmation = property(get_ShowConfirmation, put_ShowConfirmation)
class _VoiceCommandManager_Meta_(ComPtr.__class__):
    pass
class VoiceCommandManager(ComPtr, metaclass=_VoiceCommandManager_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechRecognition.VoiceCommandManager'
    @winrt_classmethod
    def InstallCommandSetsFromStorageFileAsync(cls: win32more.Windows.Media.SpeechRecognition.IVoiceCommandManager, file: win32more.Windows.Storage.StorageFile) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_classmethod
    def get_InstalledCommandSets(cls: win32more.Windows.Media.SpeechRecognition.IVoiceCommandManager) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Media.SpeechRecognition.VoiceCommandSet]: ...
    _VoiceCommandManager_Meta_.InstalledCommandSets = property(get_InstalledCommandSets, None)
class VoiceCommandSet(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.SpeechRecognition.IVoiceCommandSet
    _classid_ = 'Windows.Media.SpeechRecognition.VoiceCommandSet'
    @winrt_mixinmethod
    def get_Language(self: win32more.Windows.Media.SpeechRecognition.IVoiceCommandSet) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.Media.SpeechRecognition.IVoiceCommandSet) -> WinRT_String: ...
    @winrt_mixinmethod
    def SetPhraseListAsync(self: win32more.Windows.Media.SpeechRecognition.IVoiceCommandSet, phraseListName: WinRT_String, phraseList: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncAction: ...
    Language = property(get_Language, None)
    Name = property(get_Name, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Graphics
import win32more.Windows.Graphics.Capture
import win32more.Windows.Graphics.DirectX
import win32more.Windows.Graphics.DirectX.Direct3D11
import win32more.Windows.Security.Authorization.AppCapabilityAccess
import win32more.Windows.System
import win32more.Windows.UI
import win32more.Windows.UI.Composition
import win32more.Windows.Win32.System.WinRT
class Direct3D11CaptureFrame(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Graphics.Capture.IDirect3D11CaptureFrame
    _classid_ = 'Windows.Graphics.Capture.Direct3D11CaptureFrame'
    @winrt_mixinmethod
    def get_Surface(self: win32more.Windows.Graphics.Capture.IDirect3D11CaptureFrame) -> win32more.Windows.Graphics.DirectX.Direct3D11.IDirect3DSurface: ...
    @winrt_mixinmethod
    def get_SystemRelativeTime(self: win32more.Windows.Graphics.Capture.IDirect3D11CaptureFrame) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_ContentSize(self: win32more.Windows.Graphics.Capture.IDirect3D11CaptureFrame) -> win32more.Windows.Graphics.SizeInt32: ...
    @winrt_mixinmethod
    def get_DirtyRegions(self: win32more.Windows.Graphics.Capture.IDirect3D11CaptureFrame2) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.RectInt32]: ...
    @winrt_mixinmethod
    def get_DirtyRegionMode(self: win32more.Windows.Graphics.Capture.IDirect3D11CaptureFrame2) -> win32more.Windows.Graphics.Capture.GraphicsCaptureDirtyRegionMode: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    ContentSize = property(get_ContentSize, None)
    DirtyRegionMode = property(get_DirtyRegionMode, None)
    DirtyRegions = property(get_DirtyRegions, None)
    Surface = property(get_Surface, None)
    SystemRelativeTime = property(get_SystemRelativeTime, None)
class Direct3D11CaptureFramePool(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Graphics.Capture.IDirect3D11CaptureFramePool
    _classid_ = 'Windows.Graphics.Capture.Direct3D11CaptureFramePool'
    @winrt_mixinmethod
    def Recreate(self: win32more.Windows.Graphics.Capture.IDirect3D11CaptureFramePool, device: win32more.Windows.Graphics.DirectX.Direct3D11.IDirect3DDevice, pixelFormat: win32more.Windows.Graphics.DirectX.DirectXPixelFormat, numberOfBuffers: Int32, size: win32more.Windows.Graphics.SizeInt32) -> Void: ...
    @winrt_mixinmethod
    def TryGetNextFrame(self: win32more.Windows.Graphics.Capture.IDirect3D11CaptureFramePool) -> win32more.Windows.Graphics.Capture.Direct3D11CaptureFrame: ...
    @winrt_mixinmethod
    def add_FrameArrived(self: win32more.Windows.Graphics.Capture.IDirect3D11CaptureFramePool, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Capture.Direct3D11CaptureFramePool, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FrameArrived(self: win32more.Windows.Graphics.Capture.IDirect3D11CaptureFramePool, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def CreateCaptureSession(self: win32more.Windows.Graphics.Capture.IDirect3D11CaptureFramePool, item: win32more.Windows.Graphics.Capture.GraphicsCaptureItem) -> win32more.Windows.Graphics.Capture.GraphicsCaptureSession: ...
    @winrt_mixinmethod
    def get_DispatcherQueue(self: win32more.Windows.Graphics.Capture.IDirect3D11CaptureFramePool) -> win32more.Windows.System.DispatcherQueue: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_classmethod
    def CreateFreeThreaded(cls: win32more.Windows.Graphics.Capture.IDirect3D11CaptureFramePoolStatics2, device: win32more.Windows.Graphics.DirectX.Direct3D11.IDirect3DDevice, pixelFormat: win32more.Windows.Graphics.DirectX.DirectXPixelFormat, numberOfBuffers: Int32, size: win32more.Windows.Graphics.SizeInt32) -> win32more.Windows.Graphics.Capture.Direct3D11CaptureFramePool: ...
    @winrt_classmethod
    def Create(cls: win32more.Windows.Graphics.Capture.IDirect3D11CaptureFramePoolStatics, device: win32more.Windows.Graphics.DirectX.Direct3D11.IDirect3DDevice, pixelFormat: win32more.Windows.Graphics.DirectX.DirectXPixelFormat, numberOfBuffers: Int32, size: win32more.Windows.Graphics.SizeInt32) -> win32more.Windows.Graphics.Capture.Direct3D11CaptureFramePool: ...
    DispatcherQueue = property(get_DispatcherQueue, None)
    FrameArrived = event()
class GraphicsCaptureAccess(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Capture.GraphicsCaptureAccess'
    @winrt_classmethod
    def RequestAccessAsync(cls: win32more.Windows.Graphics.Capture.IGraphicsCaptureAccessStatics, request: win32more.Windows.Graphics.Capture.GraphicsCaptureAccessKind) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authorization.AppCapabilityAccess.AppCapabilityAccessStatus]: ...
class GraphicsCaptureAccessKind(Enum, Int32):
    Borderless = 0
    Programmatic = 1
class GraphicsCaptureDirtyRegionMode(Enum, Int32):
    ReportOnly = 0
    ReportAndRender = 1
class GraphicsCaptureItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Capture.IGraphicsCaptureItem
    _classid_ = 'Windows.Graphics.Capture.GraphicsCaptureItem'
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Graphics.Capture.IGraphicsCaptureItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Graphics.Capture.IGraphicsCaptureItem) -> win32more.Windows.Graphics.SizeInt32: ...
    @winrt_mixinmethod
    def add_Closed(self: win32more.Windows.Graphics.Capture.IGraphicsCaptureItem, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Capture.GraphicsCaptureItem, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closed(self: win32more.Windows.Graphics.Capture.IGraphicsCaptureItem, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def TryCreateFromWindowId(cls: win32more.Windows.Graphics.Capture.IGraphicsCaptureItemStatics2, windowId: win32more.Windows.UI.WindowId) -> win32more.Windows.Graphics.Capture.GraphicsCaptureItem: ...
    @winrt_classmethod
    def TryCreateFromDisplayId(cls: win32more.Windows.Graphics.Capture.IGraphicsCaptureItemStatics2, displayId: win32more.Windows.Graphics.DisplayId) -> win32more.Windows.Graphics.Capture.GraphicsCaptureItem: ...
    @winrt_classmethod
    def CreateFromVisual(cls: win32more.Windows.Graphics.Capture.IGraphicsCaptureItemStatics, visual: win32more.Windows.UI.Composition.Visual) -> win32more.Windows.Graphics.Capture.GraphicsCaptureItem: ...
    DisplayName = property(get_DisplayName, None)
    Size = property(get_Size, None)
    Closed = event()
class GraphicsCapturePicker(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Capture.IGraphicsCapturePicker
    _classid_ = 'Windows.Graphics.Capture.GraphicsCapturePicker'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Graphics.Capture.GraphicsCapturePicker.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Graphics.Capture.GraphicsCapturePicker: ...
    @winrt_mixinmethod
    def PickSingleItemAsync(self: win32more.Windows.Graphics.Capture.IGraphicsCapturePicker) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Capture.GraphicsCaptureItem]: ...
class GraphicsCaptureSession(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Graphics.Capture.IGraphicsCaptureSession
    _classid_ = 'Windows.Graphics.Capture.GraphicsCaptureSession'
    @winrt_mixinmethod
    def StartCapture(self: win32more.Windows.Graphics.Capture.IGraphicsCaptureSession) -> Void: ...
    @winrt_mixinmethod
    def get_IsCursorCaptureEnabled(self: win32more.Windows.Graphics.Capture.IGraphicsCaptureSession2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsCursorCaptureEnabled(self: win32more.Windows.Graphics.Capture.IGraphicsCaptureSession2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsBorderRequired(self: win32more.Windows.Graphics.Capture.IGraphicsCaptureSession3) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsBorderRequired(self: win32more.Windows.Graphics.Capture.IGraphicsCaptureSession3, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_DirtyRegionMode(self: win32more.Windows.Graphics.Capture.IGraphicsCaptureSession4) -> win32more.Windows.Graphics.Capture.GraphicsCaptureDirtyRegionMode: ...
    @winrt_mixinmethod
    def put_DirtyRegionMode(self: win32more.Windows.Graphics.Capture.IGraphicsCaptureSession4, value: win32more.Windows.Graphics.Capture.GraphicsCaptureDirtyRegionMode) -> Void: ...
    @winrt_mixinmethod
    def get_MinUpdateInterval(self: win32more.Windows.Graphics.Capture.IGraphicsCaptureSession5) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_MinUpdateInterval(self: win32more.Windows.Graphics.Capture.IGraphicsCaptureSession5, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_IncludeSecondaryWindows(self: win32more.Windows.Graphics.Capture.IGraphicsCaptureSession6) -> Boolean: ...
    @winrt_mixinmethod
    def put_IncludeSecondaryWindows(self: win32more.Windows.Graphics.Capture.IGraphicsCaptureSession6, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_classmethod
    def IsSupported(cls: win32more.Windows.Graphics.Capture.IGraphicsCaptureSessionStatics) -> Boolean: ...
    DirtyRegionMode = property(get_DirtyRegionMode, put_DirtyRegionMode)
    IncludeSecondaryWindows = property(get_IncludeSecondaryWindows, put_IncludeSecondaryWindows)
    IsBorderRequired = property(get_IsBorderRequired, put_IsBorderRequired)
    IsCursorCaptureEnabled = property(get_IsCursorCaptureEnabled, put_IsCursorCaptureEnabled)
    MinUpdateInterval = property(get_MinUpdateInterval, put_MinUpdateInterval)
class IDirect3D11CaptureFrame(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Capture.IDirect3D11CaptureFrame'
    _iid_ = Guid('{fa50c623-38da-4b32-acf3-fa9734ad800e}')
    @winrt_commethod(6)
    def get_Surface(self) -> win32more.Windows.Graphics.DirectX.Direct3D11.IDirect3DSurface: ...
    @winrt_commethod(7)
    def get_SystemRelativeTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(8)
    def get_ContentSize(self) -> win32more.Windows.Graphics.SizeInt32: ...
    ContentSize = property(get_ContentSize, None)
    Surface = property(get_Surface, None)
    SystemRelativeTime = property(get_SystemRelativeTime, None)
class IDirect3D11CaptureFrame2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Capture.IDirect3D11CaptureFrame2'
    _iid_ = Guid('{37869cfa-2b48-5ebf-9afb-dffd805defdb}')
    @winrt_commethod(6)
    def get_DirtyRegions(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.RectInt32]: ...
    @winrt_commethod(7)
    def get_DirtyRegionMode(self) -> win32more.Windows.Graphics.Capture.GraphicsCaptureDirtyRegionMode: ...
    DirtyRegionMode = property(get_DirtyRegionMode, None)
    DirtyRegions = property(get_DirtyRegions, None)
class IDirect3D11CaptureFramePool(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Capture.IDirect3D11CaptureFramePool'
    _iid_ = Guid('{24eb6d22-1975-422e-82e7-780dbd8ddf24}')
    @winrt_commethod(6)
    def Recreate(self, device: win32more.Windows.Graphics.DirectX.Direct3D11.IDirect3DDevice, pixelFormat: win32more.Windows.Graphics.DirectX.DirectXPixelFormat, numberOfBuffers: Int32, size: win32more.Windows.Graphics.SizeInt32) -> Void: ...
    @winrt_commethod(7)
    def TryGetNextFrame(self) -> win32more.Windows.Graphics.Capture.Direct3D11CaptureFrame: ...
    @winrt_commethod(8)
    def add_FrameArrived(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Capture.Direct3D11CaptureFramePool, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_FrameArrived(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def CreateCaptureSession(self, item: win32more.Windows.Graphics.Capture.GraphicsCaptureItem) -> win32more.Windows.Graphics.Capture.GraphicsCaptureSession: ...
    @winrt_commethod(11)
    def get_DispatcherQueue(self) -> win32more.Windows.System.DispatcherQueue: ...
    DispatcherQueue = property(get_DispatcherQueue, None)
    FrameArrived = event()
class IDirect3D11CaptureFramePoolStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Capture.IDirect3D11CaptureFramePoolStatics'
    _iid_ = Guid('{7784056a-67aa-4d53-ae54-1088d5a8ca21}')
    @winrt_commethod(6)
    def Create(self, device: win32more.Windows.Graphics.DirectX.Direct3D11.IDirect3DDevice, pixelFormat: win32more.Windows.Graphics.DirectX.DirectXPixelFormat, numberOfBuffers: Int32, size: win32more.Windows.Graphics.SizeInt32) -> win32more.Windows.Graphics.Capture.Direct3D11CaptureFramePool: ...
class IDirect3D11CaptureFramePoolStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Capture.IDirect3D11CaptureFramePoolStatics2'
    _iid_ = Guid('{589b103f-6bbc-5df5-a991-02e28b3b66d5}')
    @winrt_commethod(6)
    def CreateFreeThreaded(self, device: win32more.Windows.Graphics.DirectX.Direct3D11.IDirect3DDevice, pixelFormat: win32more.Windows.Graphics.DirectX.DirectXPixelFormat, numberOfBuffers: Int32, size: win32more.Windows.Graphics.SizeInt32) -> win32more.Windows.Graphics.Capture.Direct3D11CaptureFramePool: ...
class IGraphicsCaptureAccessStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Capture.IGraphicsCaptureAccessStatics'
    _iid_ = Guid('{743ed370-06ec-5040-a58a-901f0f757095}')
    @winrt_commethod(6)
    def RequestAccessAsync(self, request: win32more.Windows.Graphics.Capture.GraphicsCaptureAccessKind) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authorization.AppCapabilityAccess.AppCapabilityAccessStatus]: ...
class IGraphicsCaptureItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Capture.IGraphicsCaptureItem'
    _iid_ = Guid('{79c3f95b-31f7-4ec2-a464-632ef5d30760}')
    @winrt_commethod(6)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Size(self) -> win32more.Windows.Graphics.SizeInt32: ...
    @winrt_commethod(8)
    def add_Closed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Capture.GraphicsCaptureItem, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_Closed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    DisplayName = property(get_DisplayName, None)
    Size = property(get_Size, None)
    Closed = event()
class IGraphicsCaptureItemStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Capture.IGraphicsCaptureItemStatics'
    _iid_ = Guid('{a87ebea5-457c-5788-ab47-0cf1d3637e74}')
    @winrt_commethod(6)
    def CreateFromVisual(self, visual: win32more.Windows.UI.Composition.Visual) -> win32more.Windows.Graphics.Capture.GraphicsCaptureItem: ...
class IGraphicsCaptureItemStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Capture.IGraphicsCaptureItemStatics2'
    _iid_ = Guid('{3b92acc9-e584-5862-bf5c-9c316c6d2dbb}')
    @winrt_commethod(6)
    def TryCreateFromWindowId(self, windowId: win32more.Windows.UI.WindowId) -> win32more.Windows.Graphics.Capture.GraphicsCaptureItem: ...
    @winrt_commethod(7)
    def TryCreateFromDisplayId(self, displayId: win32more.Windows.Graphics.DisplayId) -> win32more.Windows.Graphics.Capture.GraphicsCaptureItem: ...
class IGraphicsCapturePicker(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Capture.IGraphicsCapturePicker'
    _iid_ = Guid('{5a1711b3-ad79-4b4a-9336-1318fdde3539}')
    @winrt_commethod(6)
    def PickSingleItemAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Capture.GraphicsCaptureItem]: ...
class IGraphicsCaptureSession(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Capture.IGraphicsCaptureSession'
    _iid_ = Guid('{814e42a9-f70f-4ad7-939b-fddcc6eb880d}')
    @winrt_commethod(6)
    def StartCapture(self) -> Void: ...
class IGraphicsCaptureSession2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Capture.IGraphicsCaptureSession2'
    _iid_ = Guid('{2c39ae40-7d2e-5044-804e-8b6799d4cf9e}')
    @winrt_commethod(6)
    def get_IsCursorCaptureEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsCursorCaptureEnabled(self, value: Boolean) -> Void: ...
    IsCursorCaptureEnabled = property(get_IsCursorCaptureEnabled, put_IsCursorCaptureEnabled)
class IGraphicsCaptureSession3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Capture.IGraphicsCaptureSession3'
    _iid_ = Guid('{f2cdd966-22ae-5ea1-9596-3a289344c3be}')
    @winrt_commethod(6)
    def get_IsBorderRequired(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsBorderRequired(self, value: Boolean) -> Void: ...
    IsBorderRequired = property(get_IsBorderRequired, put_IsBorderRequired)
class IGraphicsCaptureSession4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Capture.IGraphicsCaptureSession4'
    _iid_ = Guid('{ae99813c-c257-5759-8ed0-668c9b557ed4}')
    @winrt_commethod(6)
    def get_DirtyRegionMode(self) -> win32more.Windows.Graphics.Capture.GraphicsCaptureDirtyRegionMode: ...
    @winrt_commethod(7)
    def put_DirtyRegionMode(self, value: win32more.Windows.Graphics.Capture.GraphicsCaptureDirtyRegionMode) -> Void: ...
    DirtyRegionMode = property(get_DirtyRegionMode, put_DirtyRegionMode)
class IGraphicsCaptureSession5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Capture.IGraphicsCaptureSession5'
    _iid_ = Guid('{67c0ea62-1f85-5061-925a-239be0ac09cb}')
    @winrt_commethod(6)
    def get_MinUpdateInterval(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(7)
    def put_MinUpdateInterval(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    MinUpdateInterval = property(get_MinUpdateInterval, put_MinUpdateInterval)
class IGraphicsCaptureSession6(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Capture.IGraphicsCaptureSession6'
    _iid_ = Guid('{d7419236-be20-5e9f-bcd6-c4e98fd6afdc}')
    @winrt_commethod(6)
    def get_IncludeSecondaryWindows(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IncludeSecondaryWindows(self, value: Boolean) -> Void: ...
    IncludeSecondaryWindows = property(get_IncludeSecondaryWindows, put_IncludeSecondaryWindows)
class IGraphicsCaptureSessionStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Capture.IGraphicsCaptureSessionStatics'
    _iid_ = Guid('{2224a540-5974-49aa-b232-0882536f4cb5}')
    @winrt_commethod(6)
    def IsSupported(self) -> Boolean: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.UI.Xaml
import win32more.Windows.UI.Xaml.Media.Media3D
import win32more.Windows.Win32.System.WinRT
class _CompositeTransform3D_Meta_(ComPtr.__class__):
    pass
class CompositeTransform3D(ComPtr, metaclass=_CompositeTransform3D_Meta_):
    extends: win32more.Windows.UI.Xaml.Media.Media3D.Transform3D
    default_interface: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D
    _classid_ = 'Windows.UI.Xaml.Media.Media3D.CompositeTransform3D'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Media.Media3D.CompositeTransform3D.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Media.Media3D.CompositeTransform3D: ...
    @winrt_mixinmethod
    def get_CenterX(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_CenterX(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_CenterY(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_CenterY(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_CenterZ(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_CenterZ(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_RotationX(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_RotationX(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_RotationY(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_RotationY(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_RotationZ(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_RotationZ(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ScaleX(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_ScaleX(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ScaleY(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_ScaleY(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ScaleZ(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_ScaleZ(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_TranslateX(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_TranslateX(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_TranslateY(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_TranslateY(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_TranslateZ(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_TranslateZ(self: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D, value: Double) -> Void: ...
    @winrt_classmethod
    def get_CenterXProperty(cls: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CenterYProperty(cls: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CenterZProperty(cls: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RotationXProperty(cls: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RotationYProperty(cls: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RotationZProperty(cls: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ScaleXProperty(cls: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ScaleYProperty(cls: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ScaleZProperty(cls: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TranslateXProperty(cls: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TranslateYProperty(cls: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TranslateZProperty(cls: win32more.Windows.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CenterX = property(get_CenterX, put_CenterX)
    CenterY = property(get_CenterY, put_CenterY)
    CenterZ = property(get_CenterZ, put_CenterZ)
    RotationX = property(get_RotationX, put_RotationX)
    RotationY = property(get_RotationY, put_RotationY)
    RotationZ = property(get_RotationZ, put_RotationZ)
    ScaleX = property(get_ScaleX, put_ScaleX)
    ScaleY = property(get_ScaleY, put_ScaleY)
    ScaleZ = property(get_ScaleZ, put_ScaleZ)
    TranslateX = property(get_TranslateX, put_TranslateX)
    TranslateY = property(get_TranslateY, put_TranslateY)
    TranslateZ = property(get_TranslateZ, put_TranslateZ)
    _CompositeTransform3D_Meta_.CenterXProperty = property(get_CenterXProperty, None)
    _CompositeTransform3D_Meta_.CenterYProperty = property(get_CenterYProperty, None)
    _CompositeTransform3D_Meta_.CenterZProperty = property(get_CenterZProperty, None)
    _CompositeTransform3D_Meta_.RotationXProperty = property(get_RotationXProperty, None)
    _CompositeTransform3D_Meta_.RotationYProperty = property(get_RotationYProperty, None)
    _CompositeTransform3D_Meta_.RotationZProperty = property(get_RotationZProperty, None)
    _CompositeTransform3D_Meta_.ScaleXProperty = property(get_ScaleXProperty, None)
    _CompositeTransform3D_Meta_.ScaleYProperty = property(get_ScaleYProperty, None)
    _CompositeTransform3D_Meta_.ScaleZProperty = property(get_ScaleZProperty, None)
    _CompositeTransform3D_Meta_.TranslateXProperty = property(get_TranslateXProperty, None)
    _CompositeTransform3D_Meta_.TranslateYProperty = property(get_TranslateYProperty, None)
    _CompositeTransform3D_Meta_.TranslateZProperty = property(get_TranslateZProperty, None)
class ICompositeTransform3D(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Media.Media3D.ICompositeTransform3D'
    _iid_ = Guid('{8977cb01-af8d-4af5-b084-c08eb9704abe}')
    @winrt_commethod(6)
    def get_CenterX(self) -> Double: ...
    @winrt_commethod(7)
    def put_CenterX(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_CenterY(self) -> Double: ...
    @winrt_commethod(9)
    def put_CenterY(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_CenterZ(self) -> Double: ...
    @winrt_commethod(11)
    def put_CenterZ(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_RotationX(self) -> Double: ...
    @winrt_commethod(13)
    def put_RotationX(self, value: Double) -> Void: ...
    @winrt_commethod(14)
    def get_RotationY(self) -> Double: ...
    @winrt_commethod(15)
    def put_RotationY(self, value: Double) -> Void: ...
    @winrt_commethod(16)
    def get_RotationZ(self) -> Double: ...
    @winrt_commethod(17)
    def put_RotationZ(self, value: Double) -> Void: ...
    @winrt_commethod(18)
    def get_ScaleX(self) -> Double: ...
    @winrt_commethod(19)
    def put_ScaleX(self, value: Double) -> Void: ...
    @winrt_commethod(20)
    def get_ScaleY(self) -> Double: ...
    @winrt_commethod(21)
    def put_ScaleY(self, value: Double) -> Void: ...
    @winrt_commethod(22)
    def get_ScaleZ(self) -> Double: ...
    @winrt_commethod(23)
    def put_ScaleZ(self, value: Double) -> Void: ...
    @winrt_commethod(24)
    def get_TranslateX(self) -> Double: ...
    @winrt_commethod(25)
    def put_TranslateX(self, value: Double) -> Void: ...
    @winrt_commethod(26)
    def get_TranslateY(self) -> Double: ...
    @winrt_commethod(27)
    def put_TranslateY(self, value: Double) -> Void: ...
    @winrt_commethod(28)
    def get_TranslateZ(self) -> Double: ...
    @winrt_commethod(29)
    def put_TranslateZ(self, value: Double) -> Void: ...
    CenterX = property(get_CenterX, put_CenterX)
    CenterY = property(get_CenterY, put_CenterY)
    CenterZ = property(get_CenterZ, put_CenterZ)
    RotationX = property(get_RotationX, put_RotationX)
    RotationY = property(get_RotationY, put_RotationY)
    RotationZ = property(get_RotationZ, put_RotationZ)
    ScaleX = property(get_ScaleX, put_ScaleX)
    ScaleY = property(get_ScaleY, put_ScaleY)
    ScaleZ = property(get_ScaleZ, put_ScaleZ)
    TranslateX = property(get_TranslateX, put_TranslateX)
    TranslateY = property(get_TranslateY, put_TranslateY)
    TranslateZ = property(get_TranslateZ, put_TranslateZ)
class ICompositeTransform3DStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Media.Media3D.ICompositeTransform3DStatics'
    _iid_ = Guid('{ddbf4d67-2a25-48f3-9808-c51ec3d55bec}')
    @winrt_commethod(6)
    def get_CenterXProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CenterYProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_CenterZProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_RotationXProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_RotationYProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_RotationZProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ScaleXProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_ScaleYProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_ScaleZProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_TranslateXProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_TranslateYProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_TranslateZProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    CenterXProperty = property(get_CenterXProperty, None)
    CenterYProperty = property(get_CenterYProperty, None)
    CenterZProperty = property(get_CenterZProperty, None)
    RotationXProperty = property(get_RotationXProperty, None)
    RotationYProperty = property(get_RotationYProperty, None)
    RotationZProperty = property(get_RotationZProperty, None)
    ScaleXProperty = property(get_ScaleXProperty, None)
    ScaleYProperty = property(get_ScaleYProperty, None)
    ScaleZProperty = property(get_ScaleZProperty, None)
    TranslateXProperty = property(get_TranslateXProperty, None)
    TranslateYProperty = property(get_TranslateYProperty, None)
    TranslateZProperty = property(get_TranslateZProperty, None)
class IMatrix3DHelper(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Media.Media3D.IMatrix3DHelper'
    _iid_ = Guid('{e48c10ef-9927-4c9b-8213-07775512ba04}')
class IMatrix3DHelperStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Media.Media3D.IMatrix3DHelperStatics'
    _iid_ = Guid('{9264545e-e158-4e74-8899-689160bd2f8c}')
    @winrt_commethod(6)
    def get_Identity(self) -> win32more.Windows.UI.Xaml.Media.Media3D.Matrix3D: ...
    @winrt_commethod(7)
    def Multiply(self, matrix1: win32more.Windows.UI.Xaml.Media.Media3D.Matrix3D, matrix2: win32more.Windows.UI.Xaml.Media.Media3D.Matrix3D) -> win32more.Windows.UI.Xaml.Media.Media3D.Matrix3D: ...
    @winrt_commethod(8)
    def FromElements(self, m11: Double, m12: Double, m13: Double, m14: Double, m21: Double, m22: Double, m23: Double, m24: Double, m31: Double, m32: Double, m33: Double, m34: Double, offsetX: Double, offsetY: Double, offsetZ: Double, m44: Double) -> win32more.Windows.UI.Xaml.Media.Media3D.Matrix3D: ...
    @winrt_commethod(9)
    def GetHasInverse(self, target: win32more.Windows.UI.Xaml.Media.Media3D.Matrix3D) -> Boolean: ...
    @winrt_commethod(10)
    def GetIsIdentity(self, target: win32more.Windows.UI.Xaml.Media.Media3D.Matrix3D) -> Boolean: ...
    @winrt_commethod(11)
    def Invert(self, target: win32more.Windows.UI.Xaml.Media.Media3D.Matrix3D) -> win32more.Windows.UI.Xaml.Media.Media3D.Matrix3D: ...
    Identity = property(get_Identity, None)
class IPerspectiveTransform3D(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Media.Media3D.IPerspectiveTransform3D'
    _iid_ = Guid('{9a7b532a-30f9-40a1-96c9-c59d87f95ac3}')
    @winrt_commethod(6)
    def get_Depth(self) -> Double: ...
    @winrt_commethod(7)
    def put_Depth(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_OffsetX(self) -> Double: ...
    @winrt_commethod(9)
    def put_OffsetX(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_OffsetY(self) -> Double: ...
    @winrt_commethod(11)
    def put_OffsetY(self, value: Double) -> Void: ...
    Depth = property(get_Depth, put_Depth)
    OffsetX = property(get_OffsetX, put_OffsetX)
    OffsetY = property(get_OffsetY, put_OffsetY)
class IPerspectiveTransform3DStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Media.Media3D.IPerspectiveTransform3DStatics'
    _iid_ = Guid('{8e6f6400-620c-48c7-844d-3f0984da5b17}')
    @winrt_commethod(6)
    def get_DepthProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_OffsetXProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_OffsetYProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DepthProperty = property(get_DepthProperty, None)
    OffsetXProperty = property(get_OffsetXProperty, None)
    OffsetYProperty = property(get_OffsetYProperty, None)
class ITransform3D(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Media.Media3D.ITransform3D'
    _iid_ = Guid('{ae3ed43a-a9fc-4c31-86cd-56d9ca251a69}')
class ITransform3DFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Media.Media3D.ITransform3DFactory'
    _iid_ = Guid('{052c1f7a-8d73-48cd-bbb8-d00434caae5d}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Media.Media3D.Transform3D: ...
class Matrix3D(Structure):
    M11: Double
    M12: Double
    M13: Double
    M14: Double
    M21: Double
    M22: Double
    M23: Double
    M24: Double
    M31: Double
    M32: Double
    M33: Double
    M34: Double
    OffsetX: Double
    OffsetY: Double
    OffsetZ: Double
    M44: Double
class _Matrix3DHelper_Meta_(ComPtr.__class__):
    pass
class Matrix3DHelper(ComPtr, metaclass=_Matrix3DHelper_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Media.Media3D.IMatrix3DHelper
    _classid_ = 'Windows.UI.Xaml.Media.Media3D.Matrix3DHelper'
    @winrt_classmethod
    def get_Identity(cls: win32more.Windows.UI.Xaml.Media.Media3D.IMatrix3DHelperStatics) -> win32more.Windows.UI.Xaml.Media.Media3D.Matrix3D: ...
    @winrt_classmethod
    def Multiply(cls: win32more.Windows.UI.Xaml.Media.Media3D.IMatrix3DHelperStatics, matrix1: win32more.Windows.UI.Xaml.Media.Media3D.Matrix3D, matrix2: win32more.Windows.UI.Xaml.Media.Media3D.Matrix3D) -> win32more.Windows.UI.Xaml.Media.Media3D.Matrix3D: ...
    @winrt_classmethod
    def FromElements(cls: win32more.Windows.UI.Xaml.Media.Media3D.IMatrix3DHelperStatics, m11: Double, m12: Double, m13: Double, m14: Double, m21: Double, m22: Double, m23: Double, m24: Double, m31: Double, m32: Double, m33: Double, m34: Double, offsetX: Double, offsetY: Double, offsetZ: Double, m44: Double) -> win32more.Windows.UI.Xaml.Media.Media3D.Matrix3D: ...
    @winrt_classmethod
    def GetHasInverse(cls: win32more.Windows.UI.Xaml.Media.Media3D.IMatrix3DHelperStatics, target: win32more.Windows.UI.Xaml.Media.Media3D.Matrix3D) -> Boolean: ...
    @winrt_classmethod
    def GetIsIdentity(cls: win32more.Windows.UI.Xaml.Media.Media3D.IMatrix3DHelperStatics, target: win32more.Windows.UI.Xaml.Media.Media3D.Matrix3D) -> Boolean: ...
    @winrt_classmethod
    def Invert(cls: win32more.Windows.UI.Xaml.Media.Media3D.IMatrix3DHelperStatics, target: win32more.Windows.UI.Xaml.Media.Media3D.Matrix3D) -> win32more.Windows.UI.Xaml.Media.Media3D.Matrix3D: ...
    _Matrix3DHelper_Meta_.Identity = property(get_Identity, None)
class _PerspectiveTransform3D_Meta_(ComPtr.__class__):
    pass
class PerspectiveTransform3D(ComPtr, metaclass=_PerspectiveTransform3D_Meta_):
    extends: win32more.Windows.UI.Xaml.Media.Media3D.Transform3D
    default_interface: win32more.Windows.UI.Xaml.Media.Media3D.IPerspectiveTransform3D
    _classid_ = 'Windows.UI.Xaml.Media.Media3D.PerspectiveTransform3D'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Media.Media3D.PerspectiveTransform3D.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Media.Media3D.PerspectiveTransform3D: ...
    @winrt_mixinmethod
    def get_Depth(self: win32more.Windows.UI.Xaml.Media.Media3D.IPerspectiveTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_Depth(self: win32more.Windows.UI.Xaml.Media.Media3D.IPerspectiveTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_OffsetX(self: win32more.Windows.UI.Xaml.Media.Media3D.IPerspectiveTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_OffsetX(self: win32more.Windows.UI.Xaml.Media.Media3D.IPerspectiveTransform3D, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_OffsetY(self: win32more.Windows.UI.Xaml.Media.Media3D.IPerspectiveTransform3D) -> Double: ...
    @winrt_mixinmethod
    def put_OffsetY(self: win32more.Windows.UI.Xaml.Media.Media3D.IPerspectiveTransform3D, value: Double) -> Void: ...
    @winrt_classmethod
    def get_DepthProperty(cls: win32more.Windows.UI.Xaml.Media.Media3D.IPerspectiveTransform3DStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OffsetXProperty(cls: win32more.Windows.UI.Xaml.Media.Media3D.IPerspectiveTransform3DStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OffsetYProperty(cls: win32more.Windows.UI.Xaml.Media.Media3D.IPerspectiveTransform3DStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    Depth = property(get_Depth, put_Depth)
    OffsetX = property(get_OffsetX, put_OffsetX)
    OffsetY = property(get_OffsetY, put_OffsetY)
    _PerspectiveTransform3D_Meta_.DepthProperty = property(get_DepthProperty, None)
    _PerspectiveTransform3D_Meta_.OffsetXProperty = property(get_OffsetXProperty, None)
    _PerspectiveTransform3D_Meta_.OffsetYProperty = property(get_OffsetYProperty, None)
class Transform3D(ComPtr):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Media.Media3D.ITransform3D
    _classid_ = 'Windows.UI.Xaml.Media.Media3D.Transform3D'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Media.Media3D.Transform3D.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Media.Media3D.ITransform3DFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Media.Media3D.Transform3D: ...


make_ready(__name__)
